@@ -1,6 +1,6 @@
 #[macro_use] extern crate cli_log;
 
-fn main() -> anyhow::Result<()> {
+fn main() -> Result<(), rhit::RhitError> {
     init_cli_log!();
     rhit::run()?;
     info!("bye");
